summaryrefslogtreecommitdiffstats
path: root/libglusterfs/src/defaults.c
diff options
context:
space:
mode:
Diffstat (limited to 'libglusterfs/src/defaults.c')
-rw-r--r--libglusterfs/src/defaults.c3
1 files changed, 2 insertions, 1 deletions
diff --git a/libglusterfs/src/defaults.c b/libglusterfs/src/defaults.c
index df208c8805a..be2c9c55f4c 100644
--- a/libglusterfs/src/defaults.c
+++ b/libglusterfs/src/defaults.c
@@ -1248,9 +1248,10 @@ default_notify (xlator_t *this, int32_t event, void *data, ...)
case GF_EVENT_CHILD_MODIFIED:
case GF_EVENT_CHILD_DOWN:
case GF_EVENT_CHILD_UP:
+ case GF_EVENT_AUTH_FAILED:
{
xlator_list_t *parent = this->parents;
/* Handle case of CHILD_* event specially, send it to fuse */
if (!parent && this->ctx && this->ctx->master)
xlator_notify (this->ctx->master, event, this->graph, NULL);
@@ -1248,9 +1248,10 @@ default_notify (xlator_t *this, int32_t event, void *data, ...)
{
xlator_list_t *parent = this->parents;
- /* Handle case of CHILD_* event specially, send it to fuse */
+ /* Handle case of CHILD_* & AUTH_FAILED event specially, send it to fuse */
if (!parent && this->ctx && this->ctx->master)
xlator_notify (this->ctx->master, event, this->graph, NULL);